﻿using System;
using System.Linq;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.Runtime.InteropServices;
using System.Text;

namespace ITC81DB_2
{
    public class DataStore
    {
        #region Enum
        public enum EquipmentStatus
        {
            Stop = 0,
            Start = 1,
        }

        public enum Line
        {
            Line1 = 1,
            Line2 = 2,
        }

        public enum DisplayMode
        { 
            Normal,
            Menu,
            Calibration,
            SystemSetting,
            IOTest,
            Bypass,
            EquipmentTest,
            SorterTest,
        }

        public enum DisplayStore
        {
            MainDisplay,

            BasicDataBackup,
            BasicDataStatistics,
            BasicHelp,
            BasicProduct,
            BasicTime,

            ConfiCommunication,
            ConfiHelp,
            ConfiOption,
            ConfiOptionBoard,

            EquipHelp,
            EquipInitialize,
            EquipUpdate,
            EquipFuctionSetting,
            EquipUser,
            EquipTest,
            EquipEngineer,

            InforAS,
            InforHelp,
            InforSystem,

            SystemAutoZero,
            SystemCalibration,
            SystemHelp,
            SystemIOTest,
            SystemJudgmentSetting,
            SystemExternalOutput,
            SystemSorterSetting,
        }

        public enum FormStore
        {
            FormNone = 0,
            FormMainDisplay,
            FormMenu,
        }

        public enum MainDisplayStore
        {
            //DisplayStop,
            DisplayNormal,
            DisplayXYChart,
            DisplayList,
            DisplayDataStat,
            DisplayMenu,
        }

        public enum MenuSide
        {
            Basic,
            Configuration,
            System,
            Equipment,
            Information,
        }

        public enum MenuBottomBasic
        {
            DataBackup,
            DataStatistics,
            Help,
            Product,
            Time,
        }

        public enum MenuBottomConfiguration
        {
            Communication,
            Help,
            Option,
            OptionBoard,
        }

        public enum MenuBottomEquipment
        {
            FunctionSetting,
            Help,
            Initialize,
            Test,
            Update,
            User,
            Engineer,
        }

        public enum MenuBottomSystem
        {
            AutoZero,
            Calibration,
            ExternalOutput,
            Help,
            IOTest,
            JudgmentSetting,
            SorterSetting,
        }

        public enum MenuBottomInformation
        {
            Help,
            SystemInformation,
            AS,
        }

        public enum LanguageID
        {
            Korean,
            English,
            Chinese,
            Czech,
            Russian,
            German,
        }

        public enum JudgmentStatus
        {
            Empty,
            Under,
            Pass,
            Over,
            Double,
            Metal,
            ExNg,
        }

        public enum WeightStatus
        {
            Empty,
            WeightChange,
            WeightZero,
            CalNomal,
            CalBalans,
            CalStandby,
            CalFinish,
            CalError,
        }

        public enum UserGroup
        {
            None = 0,
            Level1Operator,
            Level2Engineer,
            Level3Manager,
            Level4Developer,
            LogOff,
        }

        public enum ResponseData
        {
            NAK = 0,
            ACK = 1,
        }

        public enum UpdateCheck
        {
            Fail,
            Success,
            NotUsbMomery,
            NotUpdateFolder,
            NotFile,
        }

        public enum WeightInputMode
        { 
            Weight,
            Deviation,
        }

        public enum Step2
        {
            Step1,
            Step2,
        }

        public enum Step3
        { 
            Step1,
            Step2,
            Step3,
        }

        public enum Step4
        {
            Step1,
            Step2,
            Step3,
            Step4,
        }

        public enum EnumFileUserPassword
        {
            f0_Level1 = 0,
            f1_Level2 = 1,
            f2_Level3 = 2,
        }

        public enum EnumFileUserGroup
        { 
            f0_Level1 = 0,
            f1_Level2 = 1,
            f2_Level3 = 2,
        }
        #endregion
    }

    #region CommunicationCommand
    public class CommunicationCommand
    {
        // 불량알람
        public static readonly string AlarmNg = "Caa00";
        // 불량알람 해지
        public static readonly string AlarmNgClear = "CAA00";

        // 업다운 - 다운
        public static readonly string MotorDown = "Cmd00";
        // 업다운 - 업
        public static readonly string MotorUp = "Cmu00";

        // 중량조정모드
        public static readonly string ModeCalibration = "Csc00";
        // 노멀모드
        public static readonly string ModeNormal = "Csn00";
        // 메뉴 모드
        public static readonly string ModeMenu = "Csm00";
        // 판정설정모드
        public static readonly string ModeJudgment = "Csg00";
        // IO 테스트모드
        public static readonly string ModeIOTest = "Cst00";
        // 바이패스
        public static readonly string ModeBypass = "Csb00";
        // 장비 테스트모드
        public static readonly string ModeEquipmentTest = "Csy00";
        // 선별기 테스트모드
        public static readonly string ModeRejectorTest = "Csr00";

        // 중량조정 - 분동
        public static readonly string CalibrationBalance = "Ccb00";
        // 중량조정 - 시작
        public static readonly string CalibrationStart = "Ccs00";
        // 중량조정 - 취소
        public static readonly string CalibrationCancel = "Ccx00";
        // 중량보정 - 한자리올림
        public static readonly string CalibrationUp = "Ccu00";
        // 중량보정 - 한자리내림
        public static readonly string CalibrationDown = "Ccd00";

        // 파라미터 쓰기
        public static readonly string Write = "Pw000";
        // 파라미터 읽기
        public static readonly string Read = "Pr000";
        // Bypass To Motor
        public static readonly string BypassToMotor = "Pb000";
        // IO테스트 - OUT
        public static readonly string IOTest = "Pt000";

        // 임펠러 모터 - 정회전
        public static readonly string ImpellerMotorForward = "Cmc00";
        // 임펠러 모터 - 역회전
        public static readonly string ImpellerMotorReverse = "Cmr00";
        // 모터 - 원점초기화
        public static readonly string MotorOrigin = "Cmo00";
        // 모터 - Step
        public static readonly string MotorStep = "Cms00";

        // Cut 신호
        public static readonly string CutInpupt = "Cbc00";
        // 공장초기화
        public static readonly string Initialization = "Cbi00";
        // 운전
        public static readonly string Start = "Cbs00";
        // 정지
        public static readonly string Stop = "Cbt00";
        // 영점
        public static readonly string Zero = "Cbz00";

        // ACK
        public static readonly string ACK = "ACK";
        // NAK
        public static readonly string NAK = "NAK";
        // 운전중 중량
        public static readonly string RunWeightData = "Sr";

        // 알람 해지 - 통신에러
        public static readonly string AlarmClearCommunicationError = "Cra00";

        // 판정 - bypass 1회
        public static readonly string BypassOnce = "Cjb00";
        // 판정 - byNG 1회
        public static readonly string ByNGOnce = "Cjc00";
        // 판정 - bypass 연속 OFF
        public static readonly string BypassOFF = "Cjd00";
        // 판정 - bypass 연속 ON
        public static readonly string BypassON = "Cjd01";
        // 판정 - byNG 연속 OFF
        public static readonly string ByNGOFF = "Cje00";
        // 판정 - byNG 연속 ON
        public static readonly string ByNGON = "Cje01";
    }
    public class CommunicationID
    {
        public static readonly string MainBoard = "0";
        public static readonly string SubBoard1 = "A";
        public static readonly string SubBoard2 = "B";
        public static readonly string SubBoard3 = "C";
        public static readonly string SubBoard4 = "D";
        public static readonly string SubBoard5 = "E";
        public static readonly string SubBoard6 = "F";
        public static readonly string SubBoard7 = "G";
        public static readonly string SubBoard8 = "H";
        public static readonly string SubBoard9 = "I";
        public static readonly string SubBoard10 = "J";
        public static readonly string SubBoard11 = "K";
        public static readonly string SubBoard12 = "L";
        public static readonly string SubBoardAll = "Z";
    }
    public class CommunicationAddress
    {
        // Address None
        public static readonly string None = "0000";

        // 장비타입
        public static readonly string _1002_EquipmentType = "1002";

        // 정지계량 사용 여부
        public static readonly string _1401_IsStopWeighing = "1401";
        // OPT(옵션보드) 사용
        public static readonly string _1402_OptionBoard = "1402";
        // 외부운전 사용 여부
        public static readonly string _1403_IsExternalOperation = "1403";
        // 초기구동 사용 여부
        public static readonly string _1404_IsInitialDrive = "1404";
        // 공기압감지 사용 여부
        public static readonly string _1405_IsPressureSensing = "1405";
        // 적체센서 사용 여부
        public static readonly string _1406_IsStackSensing = "1406";
        // 선별부 동작감지 사용 여부
        public static readonly string _1407_IsSorterDetecting = "1407";
        // 메인보드1 버전 읽기
        public static readonly string _1501_ProgramVersion = "1501";

        // 품목설정 - 품번
        public static readonly string _2001_ProductNumber = "2001";
        // 품목설정 - 하한 설정값
        public static readonly string _2002_UnderRange = "2002";
        // 품목설정 - 기준 설정값
        public static readonly string _2003_PassRange = "2003";
        // 품목설정 - 상한 설정값
        public static readonly string _2004_OverRange = "2004";
        // 품목설정 - 용기 설정값
        public static readonly string _2005_TareRange = "2005";
        // 품목설정 - 하한 설정값
        public static readonly string _2006_UnderRange = "2006";
        // 품목설정 - 기준 설정값
        public static readonly string _2007_PassRange = "2007";
        // 품목설정 - 상한 설정값
        public static readonly string _2008_OverRange = "2008";
        // 품목설정 - 용기 설정값
        public static readonly string _2009_TareRange = "2009";

        // 중량조정 - 최대중량 설정값
        public static readonly string _3001_MaxWeight = "3001";
        // 중량조정 - 분동중량 설정값
        public static readonly string _3002_BalanceWeight = "3002";
        // 중량조정 - 한눈의 값
        public static readonly string _3003_Digit = "3003";
        // 중량조정 - 상수값 읽기
        public static readonly string _3601_ConstantRead = "3601";
        // 중량조정 - 파라미터 읽기
        public static readonly string _3901_ParameterRead = "3901";

        // 자동영점 - #1 모드1 시간
        public static readonly string _4001_Zero1Time = "4001";
        // 자동영점 - #1 모드1 범위
        public static readonly string _4002_Zero1Range = "4002";
        // 자동영점 - #1 모드1 변량
        public static readonly string _4003_Zero1Variate = "4003";
        // 자동영점 - #1 모드1 모드
        public static readonly string _4004_Zero1Mode = "4004";
        // 자동영점 - #1 모드2 모드
        public static readonly string _4005_Zero2Mode = "4005";
        // 자동영점 - #1 모드2 시간
        public static readonly string _4006_Zero2Time = "4006";
        // 자동영점 - #1 모드2 범위
        public static readonly string _4007_Zero2Range = "4007";
        // 자동영점 - #1 모드2 변량
        public static readonly string _4008_Zero2Variate = "4008";
        // 자동영점 - #2 모드1 시간
        public static readonly string _4021_Zero1Time = "4021";
        // 자동영점 - #2 모드1 범위
        public static readonly string _4022_Zero1Range = "4022";
        // 자동영점 - #2 모드1 변량
        public static readonly string _4023_Zero1Variate = "4023";
        // 자동영점 - #2 모드1 모드
        public static readonly string _4024_Zero1Mode = "4024";
        // 자동영점 - #2 모드2 모드
        public static readonly string _4025_Zero2Mode = "4025";
        // 자동영점 - #2 모드2 시간
        public static readonly string _4026_Zero2Time = "4026";
        // 자동영점 - #2 모드2 범위
        public static readonly string _4027_Zero2Range = "4027";
        // 자동영점 - #2 모드2 변량
        public static readonly string _4028_Zero2Variate = "4028";

        // 자동영점 - 파라미터 읽기1
        public static readonly string _4901_ParameterRead1 = "4901";
        // 자동영점 - 파라미터 읽기2
        public static readonly string _4902_ParameterRead2 = "4902";
        // 자동영점 - 파라미터 읽기3
        public static readonly string _4903_ParameterRead3 = "4903";
        // 자동영점 - 파라미터 읽기4
        public static readonly string _4904_ParameterRead4 = "4904";
        // 자동영점 - 파라미터 읽기5
        public static readonly string _4905_ParameterRead5 = "4905";
        // 자동영점 - 파라미터 읽기6
        public static readonly string _4906_ParameterRead6 = "4906";

        // 판정설정 - #1 필터
        public static readonly string _5001_Filter = "5001";
        // 판정설정 - #1 판정지연
        public static readonly string _5002_JudgmentDelayTime = "5002";
        // 판정설정 - #1 이중지연
        public static readonly string _5003_DoubleDelayTime = "5003";
        // 판정설정 - #1 판정개수
        public static readonly string _5004_JudgmentCount = "5004";
        // 판정설정 - #1 이송속도
        public static readonly string _5005_FeedSpeed = "5005";
        // 판정설정 - #1 동보정
        public static readonly string _5006_DynamicCorrection = "5006";
        // 판정설정 - #1 Feeding 컨베어 지연시간
        public static readonly string _5007_FeedingConveyorDelayTime = "5007";
        // 판정설정 - #1 Feeding 컨베어 동작시간
        public static readonly string _5008_FeedingConveyorRunTime = "5008";
        // 판정설정 - #1 배출 컨베어 지연시간
        public static readonly string _5009_DischargeConveyorDelayTime = "5009";
        // 판정설정 - #1 배출 컨베어 동작시간
        public static readonly string _5010_DischargeConveyorRunTime = "5010";
        // 판정설정 - #1 상승 지연시간
        public static readonly string _5011_UpDelayTime1 = "5011";
        // 판정설정 - #1 하강 지연시간
        public static readonly string _5012_DownDelayTime1 = "5012";
        // 판정설정 - #2 필터
        public static readonly string _5021_Filter = "5021";
        // 판정설정 - #2 판정지연
        public static readonly string _5022_JudgmentDelayTime = "5022";
        // 판정설정 - #2 이중지연
        public static readonly string _5023_DoubleDelayTime = "5023";
        // 판정설정 - #2 판정개수
        public static readonly string _5024_JudgmentCount = "5024";
        // 판정설정 - #2 이송속도
        public static readonly string _5025_FeedSpeed = "5025";
        // 판정설정 - #2 동보정
        public static readonly string _5026_DynamicCorrection = "5026";
        // 판정설정 - #2 상승 지연시간
        public static readonly string _5028_UpDelayTime2 = "5028";
        // 판정설정 - #2 하강 지연시간
        public static readonly string _5029_DownDelayTime2 = "5029";
        // 판정설정 - 선별기 테스트
        public static readonly string _5100_SorterTest = "5100";
        // 판정설정 - 선별기1 모드
        public static readonly string _5101_Sorter1Mode = "5101";
        // 판정설정 - 선별기1 지연시간
        public static readonly string _5102_Sorter1DelayTime = "5102";
        // 판정설정 - 선별기1 동작시간
        public static readonly string _5103_Sorter1RunTime = "5103";
        // 판정설정 - 선별기2 모드
        public static readonly string _5104_Sorter2Mode = "5104";
        // 판정설정 - 선별기2 지연시간
        public static readonly string _5105_Sorter2DelayTime = "5105";
        // 판정설정 - 선별기2 동작시간
        public static readonly string _5106_Sorter2RunTime = "5106";
        // 판정설정 - 외부출력1 모드
        public static readonly string _5201_ExternalOut1Mode = "5201";
        // 판정설정 - 외부출력1 지연시간
        public static readonly string _5202_ExternalOut1DelayTime = "5202";
        // 판정설정 - 외부출력1 동작시간
        public static readonly string _5203_ExternalOut1RunTime = "5203";
        // 판정설정 - 외부출력2 모드
        public static readonly string _5204_ExternalOut2Mode = "5204";
        // 판정설정 - 외부출력2 지연시간
        public static readonly string _5205_ExternalOut2DelayTime = "5205";
        // 판정설정 - 외부출력2 동작시간
        public static readonly string _5206_ExternalOut2RunTime = "5206";
        // 판정설정 - 외부출력3 모드
        public static readonly string _5207_ExternalOut3Mode = "5207";
        // 판정설정 - 외부출력3 지연시간
        public static readonly string _5208_ExternalOut3DelayTime = "5208";
        // 판정설정 - 외부출력3 동작시간
        public static readonly string _5209_ExternalOut3RunTime = "5209";
        // 판정설정 - 외부출력4 모드
        public static readonly string _5210_ExternalOut4Mode = "5210";
        // 판정설정 - 외부출력4 지연시간
        public static readonly string _5211_ExternalOut4DelayTime = "5211";
        // 판정설정 - 외부출력4 동작시간
        public static readonly string _5212_ExternalOut4RunTime = "5212";
        // 판정설정 - 외부출력9 모드
        public static readonly string _5225_ExternalOut9Mode = "5225";
        // 판정설정 - 외부출력9 지연시간
        public static readonly string _5226_ExternalOut9DelayTime = "5226";
        // 판정설정 - 외부출력9 동작시간
        public static readonly string _5227_ExternalOut9RunTime = "5227";
        // 판정설정 - 외부출력10 모드
        public static readonly string _5228_ExternalOut10Mode = "5228";
        // 판정설정 - 외부출력10 지연시간
        public static readonly string _5229_ExternalOut10DelayTime = "5229";
        // 판정설정 - 외부출력10 동작시간
        public static readonly string _5230_ExternalOut10RunTime = "5230";
        // 판정설정 - 파라미터 읽기
        public static readonly string _5901_ParameterRead = "5901";
        // 판정설정 - 스타휠 회전주기
        public static readonly string _5301_WheelCycleTime = "5301";
        // 판정설정 - 스타휠 슬롯개수
        public static readonly string _5302_WheelSlotCount = "5302";
        // 판정설정 - 스타휠 슬롯배출지연개수
        public static readonly string _5303_WheelSlotOutCount = "5303";
        // 판정설정 - 진입센서 지연시간
        public static readonly string _5304_EntrySensorDelayTime = "5304";
        // 판정설정 - 사용자정의1(선별기1모드,지연,동작,선별기2모드,지연,동작)
        public static readonly string _5901_UserDefined1 = "5901";

        // 옵션 - 부저 ON시간
        public static readonly string _6001_BuzzerOnTime = "6001";
        // 옵션 - 릴레이 동작시간
        public static readonly string _6002_RelayRunTime = "6002";
        // 옵션 - 이중진입사용여부
        public static readonly string _6005_DoubleEnter = "6005";
        // 옵션 - 채터링감지 설정
        public static readonly string _6006_Chattering = "6006";
        // 옵션 - 외부 NG 입력 사용
        public static readonly string _6007_ExternalInput = "6007";
        // 옵션 - 제품진입 미감지
        public static readonly string _6010_EntryNotDetectedWeight = "6010";
        // 옵션 - OPT2_포트
        public static readonly string _6231_OPT2Port = "6231";
        // 옵션 - OPT2_지연시간1
        public static readonly string _6232_OPT2DelayTime1 = "6232";
        // 옵션 - OPT2_지연시간2
        public static readonly string _6233_OPT2DelayTime2 = "6233";
        // 옵션 - 파라미터 읽기
        public static readonly string _6901_ParameterRead = "6901";

        // RS232 통신1 속도
        public static readonly string _7001_Serial1_BaudRate = "7001";
        // RS232 통신1 모드
        public static readonly string _7002_Serial1_Mode = "7002";
        // RS232 통신 1 속도, 모드
        public static readonly string _7003_Serial1 = "7003";

        // 통신,IO설정 - INPUT ALL
        public static readonly string _7500_InputAll = "7500";
        // 통신,IO설정 = OUTPUT1
        public static readonly string _7701_Output1 = "7701";
        // 통신,IO설정 = OUTPUT2
        public static readonly string _7702_Output2 = "7702";
        // 통신,IO설정 = OUTPUT3
        public static readonly string _7703_Output3 = "7703";
        // 통신,IO설정 = OUTPUT4
        public static readonly string _7704_Output4 = "7704";
        // 통신,IO설정 = OUTPUT5
        public static readonly string _7705_Output5 = "7705";
        // 통신,IO설정 = OUTPUT6
        public static readonly string _7706_Output6 = "7706";
        // 통신,IO설정 = OUTPUT7
        public static readonly string _7707_Output7 = "7707";
        // 통신,IO설정 = OUTPUT8
        public static readonly string _7708_Output8 = "7708";
        // 통신,IO설정 = OUTPUT9
        public static readonly string _7709_Output9 = "7709";
        // 통신,IO설정 = OUTPUT10
        public static readonly string _7710_Output10 = "7710";
        // 통신,IO설정 = OUTPUT11
        public static readonly string _7711_Output11 = "7711";
        // 통신,IO설정 = OUTPUT12
        public static readonly string _7712_Output12 = "7712";
        // 통신,IO설정 = OUTPUT13
        public static readonly string _7713_Output13 = "7713";
        // 통신,IO설정 = OUTPUT14
        public static readonly string _7714_Output14 = "7714";
        // 통신,IO설정 = OUTPUT15
        public static readonly string _7715_Output15 = "7715";
        // 통신,IO설정 = OUTPUT16
        public static readonly string _7716_Output16 = "7716";

        // 중량설정값 쓰기 #1
        public static readonly string _9003_ParameterWeightSetting = "9003";
        // 중량설정값 쓰기 #2
        public static readonly string _9012_ParameterWeightSetting = "9012";
        // 전체파라미터 쓰기 #1
        public static readonly string _9014_SystemParameterWrite = "9014";
        // 전체파라미터 쓰기 #2
        public static readonly string _9017_SystemParameterWrite = "9017";
        // 시스템파라미터 읽기 - 9507
        public static readonly string _9507_SystemParameterRead = "9507";
        // 시스템파라미터 읽기 - 9508
        public static readonly string _9508_SystemParameterRead = "9508";
        // 시스템파라미터 읽기 - 9509
        public static readonly string _9509_SystemParameterRead = "9509";
        // 시스템파라미터 읽기 - 9510
        public static readonly string _9510_SystemParameterRead = "9510";
        // 시스템파라미터 읽기 - 9511
        public static readonly string _9511_SystemParameterRead = "9511";
    }
    #endregion

    #region CommunicationServo
    public class ServoMotorParameterAddress
    {
        // Alarm Reset - 0x0049
        public static readonly int AlarmReset = 73;

        // CCW TRQ LMT - 0x00C8
        public static readonly int CCWTorqueLimit = 200;
        // CW TRQ LMT - 0x00C9
        public static readonly int CWTorqueLimit = 201;

        // Grop Speed 0 - 0x0131
        public static readonly int GropSpeed0 = 305;

        // Position CMD 0 - 0x01F4
        public static readonly int PositionCMD0 = 500;
        // Position CMD 1 - 0x01F5
        public static readonly int PositionCMD1 = 501;
        // Position CMD 2 - 0x01F6
        public static readonly int PositionCMD2 = 502;
        // Position CMD 3 - 0x01F7
        public static readonly int PositionCMD3 = 503;

        // ORG Speed 0 - 0x0258
        public static readonly int ORGSpeed0 = 600;
        // ORG Speed 1 - 0x0259
        public static readonly int ORGSpeed1 = 601;
        // Origin Offset - 0x025B
        public static readonly int OriginOffset = 603;
        // Jog Speed 0 - 0x025D
        public static readonly int JogSpeed0 = 605;

        // Angle Division - 0x02C2
        public static readonly int AngleDivision = 706;
    } 
    #endregion

    #region SystemConfigurationItem
    public class SystemConfigurationItem
    {
        #region Field
        private bool m_IsDataBackup;
        private bool m_IsLogin;
        private bool m_IsPrint1Enable;
        private bool m_IsPrint2Enable;
        
        private int m_EquipmentID;
        private int m_DecimalPlaces;
        private int m_ProductNumber;
        private int m_UsbID;
        private int m_SerialCOM1BaudRate;
        private int m_SerialCOM1Mode;
        private int m_SerialCOM3BaudRate;
        private int m_SerialCOM3Mode;
        private int m_SerialCOM4BaudRate;
        private int m_SerialCOM4Mode;
        private int m_EquipmentType;
        
        private string m_SerialNumber;
        private string m_MainBoardVersion;
        private string m_Unit;

        private bool m_IsBypassDirectionPass1;
        private bool m_IsBypassOnce1;
        private bool m_IsBypassDirectionPass2;
        private bool m_IsBypassOnce2;

        private DataStore.LanguageID m_Language;
        #endregion

        #region Constructor
        public SystemConfigurationItem()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public bool IsDataBackup
        {
            get { return this.m_IsDataBackup; }
            set { this.m_IsDataBackup = value; }
        }
        public bool IsLogin
        {
            get { return this.m_IsLogin; }
            set { this.m_IsLogin = value; }
        }
        public bool IsPrint1Enable
        {
            get { return this.m_IsPrint1Enable; }
            set { this.m_IsPrint1Enable = value; }
        }
        public bool IsPrint2Enable
        {
            get { return this.m_IsPrint2Enable; }
            set { this.m_IsPrint2Enable = value; }
        }

        public int EquipmentID
        {
            get { return this.m_EquipmentID; }
            set { this.m_EquipmentID = value; }
        } 
        public int DecimalPlaces
        {
            get { return this.m_DecimalPlaces; }
            set { this.m_DecimalPlaces = value; }
        }
        public int ProductNumber
        {
            get { return this.m_ProductNumber; }
            set { this.m_ProductNumber = value; }
        }
        public int UsbID
        {
            get { return this.m_UsbID; }
            set { this.m_UsbID = value; }
        }
        public int SerialCOM1BaudRate
        {
            get { return this.m_SerialCOM1BaudRate; }
            set { this.m_SerialCOM1BaudRate = value; }
        }
        public int SerialCOM1Mode
        {
            get { return this.m_SerialCOM1Mode; }
            set { this.m_SerialCOM1Mode = value; }
        }
        public int SerialCOM3BaudRate
        {
            get { return this.m_SerialCOM3BaudRate; }
            set { this.m_SerialCOM3BaudRate = value; }
        }
        public int SerialCOM3Mode
        {
            get { return this.m_SerialCOM3Mode; }
            set { this.m_SerialCOM3Mode = value; }
        }
        public int SerialCOM4BaudRate
        {
            get { return this.m_SerialCOM4BaudRate; }
            set { this.m_SerialCOM4BaudRate = value; }
        }
        public int SerialCOM4Mode
        {
            get { return this.m_SerialCOM4Mode; }
            set { this.m_SerialCOM4Mode = value; }
        }
        public int EquipmentType
        {
            get { return this.m_EquipmentType; }
            set { this.m_EquipmentType = value; }
        }

        public string SerialNumber
        {
            get { return this.m_SerialNumber; }
            set { this.m_SerialNumber = value; }
        }
        public string MainBoardVersion
        {
            get { return this.m_MainBoardVersion; }
            set { this.m_MainBoardVersion = value; }
        }
        public string Unit
        {
            get { return this.m_Unit; }
            set { this.m_Unit = value; }
        }

        public bool IsBypassDirectionPass1
        {
            get { return this.m_IsBypassDirectionPass1; }
            set { this.m_IsBypassDirectionPass1 = value; }
        }
        public bool IsBypassOnce1
        {
            get { return this.m_IsBypassOnce1; }
            set { this.m_IsBypassOnce1 = value; }
        }
        public bool IsBypassDirectionPass2
        {
            get { return this.m_IsBypassDirectionPass2; }
            set { this.m_IsBypassDirectionPass2 = value; }
        }
        public bool IsBypassOnce2
        {
            get { return this.m_IsBypassOnce2; }
            set { this.m_IsBypassOnce2 = value; }
        }

        public DataStore.LanguageID Language
        {
            get { return this.m_Language; }
            set { this.m_Language = value; }
        }
        #endregion

        #region Method
        public void Initialization()
        {
            this.IsDataBackup = false;
            this.IsLogin = false;
            this.IsPrint1Enable = false;
            this.IsPrint2Enable = false;

            this.EquipmentID = 1;
            this.DecimalPlaces = 1;
            this.ProductNumber = 1;
            this.UsbID = 1;
            this.SerialCOM1BaudRate = 0;
            this.SerialCOM1Mode = 0;
            this.SerialCOM3BaudRate = 0;
            this.SerialCOM3Mode = 0;
            this.SerialCOM4BaudRate = 0;
            this.SerialCOM4Mode = 0;
            this.EquipmentType = 0;
            this.IsBypassDirectionPass1 = true;
            this.IsBypassDirectionPass2 = true;
            this.IsBypassOnce1 = true;
            this.IsBypassOnce2 = true;

            this.SerialNumber = "20G0000";
            this.MainBoardVersion = "000";
            this.Unit = "g";

            this.Language = DataStore.LanguageID.Korean;
        }
        #endregion
    }
    #endregion
    #region StructSystemConfigurationItem
    [StructLayout(LayoutKind.Sequential)]
    public struct StructSystemConfigurationItem
    {
        public bool IsDataBackup;
        public bool IsLogin;

        public int EquipmentID;
        public int DecimalPlaces;
        public int ProductNumber;
        public int UsbID;
        public int SerialCOM1BaudRate;
        public int SerialCOM1Mode;
        public int SerialCOM3BaudRate;
        public int SerialCOM3Mode;
        public int SerialCOM4BaudRate;
        public int SerialCOM4Mode;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 15)]
        public string SerialNumber;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 4)]
        public string Unit;

        public DataStore.LanguageID Language;

        public bool DummyBool1;
        public bool DummyBool2;
        public bool DummyBool3;
        public bool DummyBool4;
        public bool DummyBool5;

        public int DummyInt1;
        public int DummyInt2;
        public int DummyInt3;
        public int DummyInt4;
        public int EquipmentType;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string DummyString1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string DummyString2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string DummyString3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string DummyString4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 100)]
        public string DummyString5;
    }
    #endregion

    #region ProductItem
    public class ProductItem
    {
        #region Field
        private int m_Number;

        private string m_Name;
        private string m_LotNo;
        private string m_UnderRange;
        private string m_PassRange;
        private string m_OverRange;
        private string m_TareRange;

        private int m_OverRangeDeviation;
        private int m_UnderRangeDeviation;        

        private int m_ProgressBarMaximum;
        private int m_ProgressBarMinimum;

        private Collection<int> m_CollectionNormalDistributionRange;
        private Collection<int> m_CollectionNormalDistributionViewRange;
        #endregion

        #region Constructor
        public ProductItem()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public int Number
        {
            get { return this.m_Number; }
            set { this.m_Number = value; }
        }

        public string Name
        {
            get { return this.m_Name; }
            set { this.m_Name = value; }
        }
        public string LotNo
        {
            get { return this.m_LotNo; }
            set { this.m_LotNo = value; }
        }
        public string UnderRange
        {
            get { return this.m_UnderRange; }
            set
            {
                this.m_UnderRange = value;
                this.m_UnderRangeDeviation = this.UnderRangeInt - this.PassRangeInt;

                this.ProgressBarLevelRescale();
                this.NormalDistributionRangeCalculation();
            }
        }
        public string PassRange
        {
            get { return this.m_PassRange; }
            set
            {
                this.m_PassRange = value;
             
                this.NormalDistributionRangeCalculation();
            }
        }
        public string OverRange
        {
            get { return this.m_OverRange; }
            set
            {
                this.m_OverRange = value;
                this.m_OverRangeDeviation = this.OverRangeInt - this.PassRangeInt;

                this.ProgressBarLevelRescale();
                this.NormalDistributionRangeCalculation();
            }
        }
        public string TareRange
        {
            get { return this.m_TareRange; }
            set { this.m_TareRange = value; }
        }

        public int OverRangeDeviation
        {
            get { return this.m_OverRangeDeviation; }
            //set
            //{
            //    int iValue = 0;
                
            //    iValue = this.OverRangeInt - Math.Abs(value);
                
            //    this.m_OverRange = iValue.ToString();
            //    this.m_OverRangeDeviation = value;
            //}
        }
        public int UnderRangDeviation
        {
            get { return this.m_UnderRangeDeviation; }
            //set
            //{
            //    int iValue = 0;

            //    iValue = this.UnderRangeInt - Math.Abs(value);

            //    this.m_UnderRange = iValue.ToString();
            //    this.m_UnderRangeDeviation = value; 
            //}
        } 

        public int UnderRangeInt
        {
            get
            {
                if (this.UnderRange == null)
                    return -1;
                else
                    return int.Parse(this.UnderRange);
            }
        }
        public int PassRangeInt
        {
            get
            {
                if (this.PassRange == null)
                    return -1;
                else
                    return int.Parse(this.PassRange);
            }
        }
        public int OverRangeInt
        {
            get
            {
                if (this.OverRange == null)
                    return -1;
                else
                    return int.Parse(this.OverRange);
            }
        }
        public int TareRangeInt
        {
            get { return int.Parse(this.TareRange); }
        }

        public int ProgressBarMaximum
        {
            get { return this.m_ProgressBarMaximum; }
            private set { this.m_ProgressBarMaximum = value; }
        }
        public int ProgressBarMinimum
        {
            get { return this.m_ProgressBarMinimum; }
            private set { this.m_ProgressBarMinimum = value; }
        }

        public Collection<int> CollectionNormalDistributionRange
        {
            get { return this.m_CollectionNormalDistributionRange; }
            private set { this.m_CollectionNormalDistributionRange = value; }
        }
        public Collection<int> CollectionNormalDistributionViewRange
        {
            get { return this.m_CollectionNormalDistributionViewRange; }
            private set { this.m_CollectionNormalDistributionViewRange = value; }
        } 
        #endregion

        #region Method
        public void Initialization()
        {
            this.CollectionNormalDistributionRange = new Collection<int>();
            this.CollectionNormalDistributionRange.Clear();
            for (int i = 0; i < 8; i++)
                this.CollectionNormalDistributionRange.Add(0);

            this.CollectionNormalDistributionViewRange = new Collection<int>();
            this.CollectionNormalDistributionViewRange.Clear();
            for (int i = 0; i < 9; i++)
                this.CollectionNormalDistributionViewRange.Add(0);

            this.Number = 1;
            this.Name = "ProductName 1";
            this.LotNo = "Lot 1";
            this.PassRange = "2000";
            this.UnderRange = "1000";
            this.OverRange = "3000";
            this.TareRange = "0";

            this.ProgressBarMinimum = 0;
            this.ProgressBarMaximum = 5000;
        }

        private void ProgressBarLevelRescale()
        {
            int minBar, maxBar, gap;
            int OverRange, UnderRange;

            if (this.OverRange == null || this.UnderRange == null)
                return;

            OverRange = int.Parse(this.OverRange);
            UnderRange = int.Parse(this.UnderRange);

            gap = OverRange - UnderRange;

            minBar = UnderRange - gap;
            maxBar = OverRange + gap;

            this.ProgressBarMaximum = maxBar;
            this.ProgressBarMinimum = minBar;
        }

        private void NormalDistributionRangeCalculation()
        {
            int overGap = 0, underGap = 0, gap = 0, gap1 = 0;

            if (this.OverRangeInt == -1 || this.PassRangeInt == -1 || this.UnderRangeInt == -1)
                return;

            overGap = this.OverRangeInt - this.PassRangeInt;
            underGap = this.PassRangeInt - this.UnderRangeInt;

            if (overGap > underGap)
                gap = overGap;
            else
                gap = underGap;

            gap1 = gap / 5;

            if (gap1 == 0)
                gap1 = gap;

            this.CollectionNormalDistributionViewRange[0] = gap1 * 12;
            this.CollectionNormalDistributionViewRange[1] = gap1 * 9;
            this.CollectionNormalDistributionViewRange[2] = gap1 * 6;
            this.CollectionNormalDistributionViewRange[3] = gap1 * 3;
            this.CollectionNormalDistributionViewRange[4] = 0;
            this.CollectionNormalDistributionViewRange[5] = gap1 * 3;
            this.CollectionNormalDistributionViewRange[6] = gap1 * 6;
            this.CollectionNormalDistributionViewRange[7] = gap1 * 9;
            this.CollectionNormalDistributionViewRange[8] = gap1 * 12;

            this.CollectionNormalDistributionRange[0] = this.PassRangeInt + (gap1 * 9) + 1;
            this.CollectionNormalDistributionRange[1] = this.PassRangeInt + (gap1 * 6) + 1;
            this.CollectionNormalDistributionRange[2] = this.PassRangeInt + (gap1 * 3) + 1;
            this.CollectionNormalDistributionRange[3] = this.PassRangeInt + gap1 + 1;
            this.CollectionNormalDistributionRange[4] = this.PassRangeInt - gap1 + 1;
            this.CollectionNormalDistributionRange[5] = this.PassRangeInt - (gap1 * 3) + 1;
            this.CollectionNormalDistributionRange[6] = this.PassRangeInt - (gap1 * 6) + 1;
            this.CollectionNormalDistributionRange[7] = this.PassRangeInt - (gap1 * 9) + 1;
        }
        #endregion
    }
    #endregion
    #region StructProductItem
    [StructLayout(LayoutKind.Sequential)]
    public struct StructProductItem
    {
        public int Number;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string Name;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string LotNo;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
        public string OverRange;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
        public string UnderRange;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
        public string PassRange;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
        public string TareRange;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
        public string DummyString1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
        public string DummyString2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string DummyString3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 40)]
        public string DummyString4;
    }
    #endregion
    
    #region WeightData
    public class WeightData
    {
        #region Field
        private bool m_IsLoadCellError;
        private bool m_IsEntrySensorError;
        private bool m_IsInverterError;
        private bool m_IsPressureSensingError;
        private bool m_IsEmergencyStop;
        private bool m_IsDoorInterlock;
        private bool m_IsEntryNotDetected;

        private DateTime m_StartTime;
        private DateTime m_StopTime;

        private int m_UnderCount;
        private double m_UnderSumWeight;
        
        private int m_PassCount;
        private double m_PassSumWeight;
        
        private int m_OverCount;
        private double m_OverSumWeight;
        
        private int m_ExNGCount;
        private double m_Weight;
        private DataStore.JudgmentStatus m_JudgmentStatus;
        private DataStore.WeightStatus m_Status;

        private string m_ADCValue;
        private int m_ProductionSpeed;

        private int PreviousTimeTickCount;
        private bool m_IsStart;

        private string m_WeightString;

        private Collection<int> m_CollectionNormalDistributionCount;
        #endregion

        #region Constructor
        public WeightData()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public bool IsLoadCellError
        {
            get { return this.m_IsLoadCellError; }
            set { this.m_IsLoadCellError = value; }
        }
        public bool IsEntrySensorError
        {
            get { return this.m_IsEntrySensorError; }
            set { this.m_IsEntrySensorError = value; }
        }
        public bool IsInverterError
        {
            get { return this.m_IsInverterError; }
            set { this.m_IsInverterError = value; }
        }
        public bool IsPressureSensingError
        {
            get { return this.m_IsPressureSensingError; }
            set { this.m_IsPressureSensingError = value; }
        }
        public bool IsEmergencyStop
        {
            get { return this.m_IsEmergencyStop; }
            set { this.m_IsEmergencyStop = value; }
        }
        public bool IsDoorInterlock
        {
            get { return this.m_IsDoorInterlock; }
            set { this.m_IsDoorInterlock = value; }
        }
        public bool IsEntryNotDetected
        {
            get { return this.m_IsEntryNotDetected; }
            set { this.m_IsEntryNotDetected = value; }
        }

        public DateTime StartTime
        {
            get { return this.m_StartTime; }
            set { this.m_StartTime = value; }
        }
        public DateTime StopTime
        {
            get { return this.m_StopTime; }
            set { this.m_StopTime = value; }
        } 

        public int UnderCount
        {
            get { return this.m_UnderCount; }
            set { this.m_UnderCount = value; }
        }
        public double UnderSumWeight
        {
            get { return this.m_UnderSumWeight; }
            set { this.m_UnderSumWeight = value; }
        } 
        public string UnderRatio
        {
            get
            {
                string ret = "";

                if (this.UnderCount == 0 || this.TotalCount1 == 0)
                    ret = "0.00";
                else
                    ret = string.Format("{0:##0.00}", (float.Parse(this.UnderCount.ToString()) * 100.0F) / this.TotalCount2);

                return ret;
            }
        }
        public double UnderAverage
        {
            get
            {
                double ret = 0.0;

                if (this.UnderCount == 0 || this.UnderSumWeight == 0.0)
                    ret = 0.0;
                else
                    ret = this.UnderSumWeight / this.UnderCount;

                return ret;
            }
        }
        public string UnderSumWeightKG
        {
            get 
            {
                string temp = "", ret = "";

                temp = string.Format("{0:f0}", this.UnderSumWeight);
                ret = string.Format("{0}", int.Parse(temp) / 1000);

                return ret;
            }
        }

        public int PassCount
        {
            get { return this.m_PassCount; }
            set { this.m_PassCount = value; }
        }
        public double PassSumWeight
        {
            get { return this.m_PassSumWeight; }
            set { this.m_PassSumWeight = value; }
        } 
        public string PassRatio
        {
            get
            {
                string ret = "";

                if (this.PassCount == 0 || this.TotalCount1 == 0)
                    ret = "0.00";
                else
                    ret = string.Format("{0:##0.00}", (float.Parse(this.PassCount.ToString()) * 100.0F) / this.TotalCount2);

                return ret;
            }
        }
        public double PassAverage
        {
            get 
            {
                double ret = 0.0;

                if (this.PassCount == 0 || this.PassSumWeight == 0.0)
                    ret = 0.0;
                else
                    ret = this.PassSumWeight / this.PassCount;

                return ret;
            }
        }
        public string PassSumWeightKG
        {
            get
            {
                string temp = "", ret = "";

                temp = string.Format("{0:f0}", this.PassSumWeight);
                ret = string.Format("{0}", int.Parse(temp) / 1000);

                return ret;
            }
        }

        public int OverCount
        {
            get { return this.m_OverCount; }
            set { this.m_OverCount = value; }
        }
        public double OverSumWeight
        {
            get { return this.m_OverSumWeight; }
            set { this.m_OverSumWeight = value; }
        } 
        public string OverRatio
        {
            get
            {
                string ret = "";

                if (this.OverCount == 0 || this.TotalCount1 == 0)
                    ret = "0.00";
                else
                    ret = string.Format("{0:##0.00}", (float.Parse(this.OverCount.ToString()) * 100.0F) / this.TotalCount2);

                return ret;
            }
        }
        public double OverAverage
        {
            get 
            {
                double ret = 0.0;

                if (this.OverCount == 0 || this.OverSumWeight == 0.0)
                    ret = 0.0;
                else
                    ret = this.OverSumWeight / this.OverCount;

                return ret;
            }
        }
        public string OverSumWeightKG
        {
            get
            {
                string temp = "", ret = "";

                temp = string.Format("{0:f0}", this.OverSumWeight);
                ret = string.Format("{0}", int.Parse(temp) / 1000);

                return ret;
            }
        }

        public int ExNGCount
        {
            get { return this.m_ExNGCount; }
            set { this.m_ExNGCount = value; }
        }

        public int TotalUnderOverCount
        {
            get { return this.UnderCount + this.OverCount; }
        }
        public int TotalNGCount
        {
            get { return this.UnderCount + this.OverCount + this.ExNGCount; }
        }

        /// <summary>
        /// Under+Pass+Over+ExNG
        /// </summary>
        public int TotalCount1
        {
            get { return this.UnderCount + this.PassCount + this.OverCount + this.ExNGCount; }
        }
        /// <summary>
        /// Under+Pass+Over
        /// </summary>
        public int TotalCount2
        {
            get { return this.UnderCount + this.PassCount + this.OverCount; }
        }

        public double Weight
        {
            get { return this.m_Weight; }
            set { this.m_Weight = value; }
        }

        public string ADCValue
        {
            get { return this.m_ADCValue; }
            set { this.m_ADCValue = value; }
        }

        public DataStore.JudgmentStatus JudgmentStatus
        {
            get { return this.m_JudgmentStatus; }
            set
            {
                this.m_JudgmentStatus = value;

                if (value == DataStore.JudgmentStatus.Under)
                {
                    if (this.UnderCount < 10000000)
                        this.UnderCount++;
                    else
                        this.UnderCount = 0;
                }
                else if (value == DataStore.JudgmentStatus.Pass)
                {
                    if (this.PassCount < 10000000)
                        this.PassCount++;
                    else
                        this.PassCount = 0;
                }
                else if (value == DataStore.JudgmentStatus.Over)
                {
                    if (this.OverCount < 10000000)
                        this.OverCount++;
                    else
                        this.OverCount = 0;
                }
                else if (value == DataStore.JudgmentStatus.Double || value == DataStore.JudgmentStatus.Metal
                    || value == DataStore.JudgmentStatus.ExNg)
                {
                    if (this.ExNGCount < 10000000)
                        this.ExNGCount++;
                    else
                        this.ExNGCount = 0;
                }
            }
        }

        public DataStore.WeightStatus Status
        {
            get { return this.m_Status; }
            set { this.m_Status = value; }
        }

        public int ProductionSpeed
        {
            get { return this.m_ProductionSpeed; }
            set { this.m_ProductionSpeed = value; }
        }
        public bool IsStart
        {
            get { return this.m_IsStart; }
            set { this.m_IsStart = value; }
        }

        public string WeightString
        {
            get { return this.m_WeightString; }
            set { this.m_WeightString = value; }
        }

        public Collection<int> CollectionNormalDistributionCount
        {
            get { return this.m_CollectionNormalDistributionCount; }
            set { this.m_CollectionNormalDistributionCount = value; }
        } 
        #endregion

        #region Mehtod
        public void ClearCount()
        {
            this.UnderCount = 0;
            this.UnderSumWeight = 0.0;
            this.PassCount = 0;
            this.PassSumWeight = 0.0;
            this.OverCount = 0;
            this.OverSumWeight = 0.0;
            this.ExNGCount = 0;

            this.StartTime = new DateTime(1111, 11, 11, 11, 11, 11);
            this.StopTime = new DateTime(1111, 11, 11, 11, 11, 11);

            for (int i = 0; i < this.CollectionNormalDistributionCount.Count; i++)
                this.CollectionNormalDistributionCount[i] = 0;
        }

        private void Initialization()
        {
            this.IsLoadCellError = false;
            this.IsEntrySensorError = false;
            this.IsInverterError = false;
            this.IsPressureSensingError = false;
            this.IsDoorInterlock = false;
            this.IsEntryNotDetected = false;

            this.StartTime = new DateTime(1111, 11, 11, 11, 11, 11);
            this.StopTime = new DateTime(1111, 11, 11, 11, 11, 11);
            this.UnderCount = 0;
            this.UnderSumWeight = 0.0;
            this.PassCount = 0;
            this.PassSumWeight = 0.0;
            this.OverCount = 0;
            this.OverSumWeight = 0.0;
            this.ExNGCount = 0;
            this.Weight = 0.0;
            this.ADCValue = "12345";
            this.JudgmentStatus = DataStore.JudgmentStatus.Empty;
            this.Status = DataStore.WeightStatus.Empty;
            this.ProductionSpeed = 0;
            this.WeightString = "0";

            this.CollectionNormalDistributionCount = new Collection<int>();
            this.CollectionNormalDistributionCount.Clear();
            for (int i = 0; i < 10; i++)
                this.CollectionNormalDistributionCount.Add(0);
        }

        private void ProductionSpeedCalculation()
        {
            int currentTimeTickCount = 0, gap = 0;
            double millisecond = 0.0, speed = 0.0;

            if (this.IsStart == false)
            {
                this.PreviousTimeTickCount = Environment.TickCount & Int32.MaxValue;
                this.IsStart = true;
            }
            else
            {
                currentTimeTickCount = Environment.TickCount & Int32.MaxValue;
                gap = Math.Abs(currentTimeTickCount - this.PreviousTimeTickCount);
                millisecond = gap / 1000.0;
                speed = 60 / millisecond;
                this.ProductionSpeed = int.Parse(string.Format("{0:f0}", speed));

                this.PreviousTimeTickCount = Environment.TickCount;
            }
        }

        public void WeightSum(DataStore.JudgmentStatus status)
        {
            if (status == DataStore.JudgmentStatus.Over)
                this.OverSumWeight += this.Weight;
            else if (status == DataStore.JudgmentStatus.Pass)
                this.PassSumWeight += this.Weight;
            else if (status == DataStore.JudgmentStatus.Under)
                this.UnderSumWeight += this.Weight;
        }

        public void SetNormalDistribution(Collection<int> collectionRange, string weight)
        {
            int value = 0;

            value = int.Parse(weight);

            for (int i = 0; i < this.CollectionNormalDistributionCount.Count; i++)
            {
                if (i == collectionRange.Count)
                {
                    this.CollectionNormalDistributionCount[i]++;
                    break;
                }

                if (collectionRange[i] < value)
                {
                    this.CollectionNormalDistributionCount[i]++;
                    break;
                }
            }
        }
        #endregion
    }
    #endregion
    #region StructCounter
    [StructLayout(LayoutKind.Sequential)]
    public struct StructCounterItem
    {
        public int OverCount;
        public int PassCount;
        public int UnderCount;
        public int ExNGCount;

        public int NormalDistribution1;
        public int NormalDistribution2;
        public int NormalDistribution3;
        public int NormalDistribution4;
        public int NormalDistribution5;
        public int NormalDistribution6;
        public int NormalDistribution7;
        public int NormalDistribution8;
        public int NormalDistribution9;
        public int NormalDistribution10;

        public double OverSumWeight;
        public double PassSumWeight;
        public double UnderSumWeight;

        public DateTime StartTime;
        public DateTime StopTime;

        public int DummyInt1;
        public int DummyInt2;
        public int DummyInt3;
        public int DummyInt4;
        public int DummyInt5;
    }
    #endregion

    #region JudgmentSetItem
    public class JudgmentSetItem
    {
        #region Field
        private int m_Filter;
        private int m_JudgmentDelayTime;
        private int m_DoubleDelayTime;
        private int m_JudgmentCount;
        private int m_FeedSpeed1;
        private int m_FeedSpeed2;
        private int m_FeedSpeed3;
        private double m_DynamicCorrection;

        private int m_Sorter1Mode;
        private int m_Sorter1DelayTime;
        private int m_Sorter1RunTime;
        private int m_Sorter2Mode;
        private int m_Sorter2DelayTime;
        private int m_Sorter2RunTime;

        private int m_AutoJudgmentLength;
        private int m_AutoJudgment1;
        private int m_AutoJudgment2;
        private int m_AutoJudgment3;

        private int m_DescendDelayTime;
        private int m_AscendDelayTime;
        #endregion

        #region Constructor
        public JudgmentSetItem()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public int Filter
        {
            get { return this.m_Filter; }
            set { this.m_Filter = value; }
        }
        public int JudgmentDelayTime
        {
            get { return this.m_JudgmentDelayTime; }
            set { this.m_JudgmentDelayTime = value; }
        }
        public int DoubleDelayTime
        {
            get { return this.m_DoubleDelayTime; }
            set { this.m_DoubleDelayTime = value; }
        }
        public int JudgmentCount
        {
            get { return this.m_JudgmentCount; }
            set { this.m_JudgmentCount = value; }
        }
        public int FeedSpeed1
        {
            get { return this.m_FeedSpeed1; }
            set { this.m_FeedSpeed1 = value; }
        }
        public int FeedSpeed2
        {
            get { return this.m_FeedSpeed2; }
            set { this.m_FeedSpeed2 = value; }
        }
        public int FeedSpeed3
        {
            get { return this.m_FeedSpeed3; }
            set { this.m_FeedSpeed3 = value; }
        } 
        public double DynamicCorrection
        {
            get { return this.m_DynamicCorrection; }
            set { this.m_DynamicCorrection = value; }
        }

        public int Sorter1Mode
        {
            get { return this.m_Sorter1Mode; }
            set { this.m_Sorter1Mode = value; }
        }
        public int Sorter1DelayTime
        {
            get { return this.m_Sorter1DelayTime; }
            set { this.m_Sorter1DelayTime = value; }
        }
        public int Sorter1RunTime
        {
            get { return this.m_Sorter1RunTime; }
            set { this.m_Sorter1RunTime = value; }
        }
        public int Sorter2Mode
        {
            get { return this.m_Sorter2Mode; }
            set { this.m_Sorter2Mode = value; }
        }
        public int Sorter2DelayTime
        {
            get { return this.m_Sorter2DelayTime; }
            set { this.m_Sorter2DelayTime = value; }
        }
        public int Sorter2RunTime
        {
            get { return this.m_Sorter2RunTime; }
            set { this.m_Sorter2RunTime = value; }
        }

        public int AutoJudgmentLength
        {
            get { return this.m_AutoJudgmentLength; }
            set { this.m_AutoJudgmentLength = value; }
        }
        public int AutoJudgment1
        {
            get { return this.m_AutoJudgment1; }
            set { this.m_AutoJudgment1 = value; }
        }
        public int AutoJudgment2
        {
            get { return this.m_AutoJudgment2; }
            set { this.m_AutoJudgment2 = value; }
        }
        public int AutoJudgment3
        {
            get { return this.m_AutoJudgment3; }
            set { this.m_AutoJudgment3 = value; }
        }

        public int DescendDelayTime
        {
            get { return this.m_DescendDelayTime; }
            set { this.m_DescendDelayTime = value; }
        }
        public int AscendDelayTime
        {
            get { return this.m_AscendDelayTime; }
            set { this.m_AscendDelayTime = value; }
        } 
        #endregion

        #region Method
        public void Initialization()
        {
            this.Filter = 8;
            this.JudgmentDelayTime = 1000;
            this.DoubleDelayTime = 900;
            this.JudgmentCount = 10;
            this.FeedSpeed1 = 60;
            this.FeedSpeed2 = 60;
            this.FeedSpeed3 = 60;
            this.DynamicCorrection = 1.000000;

            this.Sorter1Mode = 0;
            this.Sorter1DelayTime = 1;
            this.Sorter1RunTime = 1000;
            this.Sorter2Mode = 0;
            this.Sorter2DelayTime = 1;
            this.Sorter2RunTime = 1000;

            this.AutoJudgmentLength = 100;
            this.AutoJudgment1 = 100;
            this.AutoJudgment2 = 100;
            this.AutoJudgment3 = 100;

            this.DescendDelayTime = 400;
            this.AscendDelayTime = 200;
        }
        #endregion
    }
    #endregion
    #region Struct JudgmentSetItem
    [StructLayout(LayoutKind.Sequential)]
    public struct StructJudgmentSetItem
    {
        public int Filter;
        public int JudgmentDelayTime;
        public int DoubleDelayTime;
        public int JudgmentCount;
        public int FeedSpeed1;
        public int FeedSpeed2;
        public int FeedSpeed3;
        public double DynamicCorrection;

        public int Sorter1Mode;
        public int Sorter1DelayTime;
        public int Sorter1RunTime;
        public int Sorter2Mode;
        public int Sorter2DelayTime;
        public int Sorter2RunTime;

        public int AutoJudgmentLength;
        public int AutoJudgment1;
        public int AutoJudgment2;
        public int AutoJudgment3;

        public int DescendDelayTime;
        public int AscendDelayTime;
        public int DummyInt1;
        public int DummyInt2;
        public int DummyInt3;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string DummyString1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string DummyString2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string DummyString3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string DummyString4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string DummyString5;
    }
    #endregion

    #region CalibrationItem
    public class CalibrationItem
    {
        #region Field
        private string m_BalanceWeight;
        private string m_MaxWeight;
        private string m_Digit;
        private string m_Constant1;
        private string m_Constant2;
        #endregion

        #region Constructor
        public CalibrationItem()
        {
            this.BalanceWeight = "5000";
            this.MaxWeight = "9999";
            this.Digit = "1";
            this.Constant1 = "1.000000";
            this.Constant2 = "1.000000";
        }
        #endregion

        #region Property
        public string BalanceWeight
        {
            get { return this.m_BalanceWeight; }
            set { this.m_BalanceWeight = value; }
        }
        public string MaxWeight
        {
            get { return this.m_MaxWeight; }
            set { this.m_MaxWeight = value; }
        }
        public string Digit
        {
            get { return this.m_Digit; }
            set { this.m_Digit = value; }
        }
        public string Constant1
        {
            get { return this.m_Constant1; }
            set { this.m_Constant1 = value; }
        }
        public string Constant2
        {
            get { return this.m_Constant2; }
            set { this.m_Constant2 = value; }
        } 
        #endregion
    }
    #endregion

    #region SystemParameter9507
    public class SystemParameter9507
    {
        #region Field
        private string m_BuzzerOnTime;
        private string m_RelayOnTime;
        private string m_Chattering;
        private string m_SorterDoubleEntry;
        private string m_EntryNotDetectedWeight;
        
        private string m_Dummy1;
        private string m_Dummy2;
        private string m_Dummy3;
        private string m_Dummy4;
        private string m_Dummy5;
        private string m_Dummy6;
        private string m_Dummy7;
        private string m_Dummy8;
        private string m_Dummy9;
        private string m_Dummy10;
        private string m_Dummy11;
        private string m_Dummy12;
        #endregion

        #region Constructor
        public SystemParameter9507()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public string BuzzerOnTime
        {
            get { return this.m_BuzzerOnTime; }
            set { this.m_BuzzerOnTime = value; }
        }
        public string RelayOnTime
        {
            get { return this.m_RelayOnTime; }
            set { this.m_RelayOnTime = value; }
        }
        public string Chattering
        {
            get { return this.m_Chattering; }
            set { this.m_Chattering = value; }
        }
        public string SorterDoubleEntry
        {
            get { return this.m_SorterDoubleEntry; }
            set { this.m_SorterDoubleEntry = value; }
        }
        public string EntryNotDetectedWeight
        {
            get { return this.m_EntryNotDetectedWeight; }
            set { this.m_EntryNotDetectedWeight = value; }
        } 

        public string Dummy1
        {
            get { return this.m_Dummy1; }
            set { this.m_Dummy1 = value; }
        }
        public string Dummy2
        {
            get { return this.m_Dummy2; }
            set { this.m_Dummy2 = value; }
        }
        public string Dummy3
        {
            get { return this.m_Dummy3; }
            set { this.m_Dummy3 = value; }
        }
        public string Dummy4
        {
            get { return this.m_Dummy4; }
            set { this.m_Dummy4 = value; }
        }
        public string Dummy5
        {
            get { return this.m_Dummy5; }
            set { this.m_Dummy5 = value; }
        }
        public string Dummy6
        {
            get { return this.m_Dummy6; }
            set { this.m_Dummy6 = value; }
        }
        public string Dummy7
        {
            get { return this.m_Dummy7; }
            set { this.m_Dummy7 = value; }
        }
        public string Dummy8
        {
            get { return this.m_Dummy8; }
            set { this.m_Dummy8 = value; }
        }
        public string Dummy9
        {
            get { return this.m_Dummy9; }
            set { this.m_Dummy9 = value; }
        }
        public string Dummy10
        {
            get { return this.m_Dummy10; }
            set { this.m_Dummy10 = value; }
        }
        public string Dummy11
        {
            get { return this.m_Dummy11; }
            set { this.m_Dummy11 = value; }
        }
        public string Dummy12
        {
            get { return this.m_Dummy12; }
            set { this.m_Dummy12 = value; }
        }
        #endregion

        #region Method
        private void Initialization()
        {
            this.BuzzerOnTime = "1000";
            this.RelayOnTime = "500";
            this.Chattering = "0";
            this.SorterDoubleEntry = "0";
            this.EntryNotDetectedWeight = "0";
            
            this.Dummy1 = "0";
            this.Dummy2 = "0";
            this.Dummy3 = "0";
            this.Dummy4 = "0";
            this.Dummy5 = "0";
            this.Dummy6 = "0";
            this.Dummy7 = "0";
            this.Dummy8 = "0";
            this.Dummy9 = "0";
            this.Dummy10 = "0";
            this.Dummy11 = "0";
            this.Dummy12 = "0";
        }
        #endregion
    } 
    #endregion
    #region StructSystemParameter9507
    [StructLayout(LayoutKind.Sequential)]
    public struct StructSystemParameter9507
    {
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Serial1Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Serial1BaudRate;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string BuzzerOnTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string RelayOnTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Chattering;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string SorterDoubleEntry;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string SorterExternalNgInput;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string StopWeighting;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOperation;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string InitialDrive;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string PressureSensing;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string StackSensing;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string SorterDetecting;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OptionBoard;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string EntryNotDetectedWeight;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy5;
    }
    #endregion
    #region SystemParameter9508
    public class SystemParameter9508
    {
        #region Field
        private string m_OPT1SamplingCount;
        private string m_OPT1DelayCount;
        private string m_OPT1PulseWidth;
        private string m_OPT1IsWeightSetting;
        private string m_OPT1OverRange;
        private string m_OPT1UnderRange;
        private string m_OPT1Port;

        private string m_OPT2Port;
        private string m_OPT2DelayTime1;
        private string m_OPT2DelayTime2;

        private string m_Dummy1;
        private string m_Dummy2;
        private string m_Dummy3;
        private string m_Dummy4; 
        private string m_Dummy5;
        private string m_Dummy6;
        private string m_Dummy7;
        #endregion

        #region Constructor
        public SystemParameter9508()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public string OPT1SamplingCount
        {
            get { return this.m_OPT1SamplingCount; }
            set { this.m_OPT1SamplingCount = value; }
        }
        public string OPT1DelayCount
        {
            get { return this.m_OPT1DelayCount; }
            set { this.m_OPT1DelayCount = value; }
        }
        public string OPT1PulseWidth
        {
            get { return this.m_OPT1PulseWidth; }
            set { this.m_OPT1PulseWidth = value; }
        }
        public string OPT1IsWeightSetting
        {
            get { return this.m_OPT1IsWeightSetting; }
            set { this.m_OPT1IsWeightSetting = value; }
        }
        public string OPT1OverRange
        {
            get { return this.m_OPT1OverRange; }
            set { this.m_OPT1OverRange = value; }
        }
        public string OPT1UnderRange
        {
            get { return this.m_OPT1UnderRange; }
            set { this.m_OPT1UnderRange = value; }
        } 
        public string OPT1Port
        {
            get { return this.m_OPT1Port; }
            set { this.m_OPT1Port = value; }
        }

        public string OPT2Port
        {
            get { return this.m_OPT2Port; }
            set { this.m_OPT2Port = value; }
        }
        public string OPT2DelayTime1
        {
            get { return this.m_OPT2DelayTime1; }
            set { this.m_OPT2DelayTime1 = value; }
        }
        public string OPt2DelayTime2
        {
            get { return this.m_OPT2DelayTime2; }
            set { this.m_OPT2DelayTime2 = value; }
        }

        public string Dummy1
        {
            get { return this.m_Dummy1; }
            set { this.m_Dummy1 = value; }
        }
        public string Dummy2
        {
            get { return this.m_Dummy2; }
            set { this.m_Dummy2 = value; }
        }
        public string Dummy3
        {
            get { return this.m_Dummy3; }
            set { this.m_Dummy3 = value; }
        }
        public string Dummy4
        {
            get { return this.m_Dummy4; }
            set { this.m_Dummy4 = value; }
        }
        public string Dummy5
        {
            get { return this.m_Dummy5; }
            set { this.m_Dummy5 = value; }
        }
        public string Dummy6
        {
            get { return this.m_Dummy6; }
            set { this.m_Dummy6 = value; }
        }
        public string Dummy7
        {
            get { return this.m_Dummy7; }
            set { this.m_Dummy7 = value; }
        }
        #endregion

        #region Method
        public void Initialization()
        {
            this.OPT1SamplingCount = "0";
            this.OPT1DelayCount = "0";
            this.OPT1PulseWidth = "0";
            this.OPT1IsWeightSetting = "0";
            this.OPT1OverRange = "0";
            this.OPT1UnderRange = "0";
            this.OPT1Port = "0";

            this.OPT2Port = "0";
            this.OPT2DelayTime1 = "0";
            this.OPt2DelayTime2 = "0";

            this.Dummy1 = "0";
            this.Dummy2 = "0";
            this.Dummy3 = "0";
            this.Dummy4 = "0";
            this.Dummy5 = "0";
            this.Dummy6 = "0";
            this.Dummy7 = "0";
        }
        #endregion
    } 
    #endregion
    #region StructSystemParameter9508
    [StructLayout(LayoutKind.Sequential)]
    public struct StructSystemParameter9508
    {
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1SamplingCount;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1DelayCount;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1PulseWidth;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1IsWeightSetting;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1OverRange;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1UnderRange;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT1Port;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT2Port;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT2DelayTime1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string OPT2DelayTime2;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy5;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy6;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy7;
    }
    #endregion
    #region SystemParameter9509
    public class SystemParameter9509
    {
        #region Field
        private string m_ExternalOut1Mode;
        private string m_ExternalOut1DelayTime;
        private string m_ExternalOut1RunTime;

        private string m_ExternalOut2Mode;
        private string m_ExternalOut2DelayTime;
        private string m_ExternalOut2RunTime;

        private string m_ExternalOut3Mode;
        private string m_ExternalOut3DelayTime;
        private string m_ExternalOut3RunTime;

        private string m_ExternalOut4Mode;
        private string m_ExternalOut4DelayTime;
        private string m_ExternalOut4RunTime;

        private string m_ExternalOut9Mode;
        private string m_ExternalOut9DelayTime;
        private string m_ExternalOut9RunTime;

        private string m_ExternalOut10Mode;
        private string m_ExternalOut10DelayTime;
        private string m_ExternalOut10RunTime;

        private string m_Dummy1;
        private string m_Dummy2;
        #endregion

        #region Constructor
        public SystemParameter9509()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public string ExternalOut1Mode
        {
            get { return this.m_ExternalOut1Mode; }
            set { this.m_ExternalOut1Mode = value; }
        }
        public string ExternalOut1DelayTime
        {
            get { return this.m_ExternalOut1DelayTime; }
            set { this.m_ExternalOut1DelayTime = value; }
        }
        public string ExternalOut1RunTime
        {
            get { return this.m_ExternalOut1RunTime; }
            set { this.m_ExternalOut1RunTime = value; }
        }

        public string ExternalOut2Mode
        {
            get { return this.m_ExternalOut2Mode; }
            set { this.m_ExternalOut2Mode = value; }
        }
        public string ExternalOut2DelayTime
        {
            get { return this.m_ExternalOut2DelayTime; }
            set { this.m_ExternalOut2DelayTime = value; }
        }
        public string ExternalOut2RunTime
        {
            get { return this.m_ExternalOut2RunTime; }
            set { this.m_ExternalOut2RunTime = value; }
        }

        public string ExternalOut3Mode
        {
            get { return this.m_ExternalOut3Mode; }
            set { this.m_ExternalOut3Mode = value; }
        }
        public string ExternalOut3DelayTime
        {
            get { return this.m_ExternalOut3DelayTime; }
            set { this.m_ExternalOut3DelayTime = value; }
        }
        public string ExternalOut3RunTime
        {
            get { return this.m_ExternalOut3RunTime; }
            set { this.m_ExternalOut3RunTime = value; }
        }

        public string ExternalOut4Mode
        {
            get { return this.m_ExternalOut4Mode; }
            set { this.m_ExternalOut4Mode = value; }
        }
        public string ExternalOut4DelayTime
        {
            get { return this.m_ExternalOut4DelayTime; }
            set { this.m_ExternalOut4DelayTime = value; }
        }
        public string ExternalOut4RunTime
        {
            get { return this.m_ExternalOut4RunTime; }
            set { this.m_ExternalOut4RunTime = value; }
        }

        public string ExternalOut9Mode
        {
            get { return this.m_ExternalOut9Mode; }
            set { this.m_ExternalOut9Mode = value; }
        }
        public string ExternalOut9DelayTime
        {
            get { return this.m_ExternalOut9DelayTime; }
            set { this.m_ExternalOut9DelayTime = value; }
        }
        public string ExternalOut9RunTime
        {
            get { return this.m_ExternalOut9RunTime; }
            set { this.m_ExternalOut9RunTime = value; }
        }

        public string ExternalOut10Mode
        {
            get { return this.m_ExternalOut10Mode; }
            set { this.m_ExternalOut10Mode = value; }
        }
        public string ExternalOut10DelayTime
        {
            get { return this.m_ExternalOut10DelayTime; }
            set { this.m_ExternalOut10DelayTime = value; }
        }
        public string ExternalOut10RunTime
        {
            get { return this.m_ExternalOut10RunTime; }
            set { this.m_ExternalOut10RunTime = value; }
        }

        public string Dummy1
        {
            get { return this.m_Dummy1; }
            set { this.m_Dummy1 = value; }
        }
        public string Dummy2
        {
            get { return this.m_Dummy2; }
            set { this.m_Dummy2 = value; }
        }
        #endregion

        #region Method
        private void Initialization()
        {
            this.ExternalOut1Mode = "0";
            this.ExternalOut1DelayTime = "0";
            this.ExternalOut1RunTime = "0";

            this.ExternalOut2Mode = "0";
            this.ExternalOut2DelayTime = "0";
            this.ExternalOut2RunTime = "0";

            this.ExternalOut3Mode = "0";
            this.ExternalOut3DelayTime = "0";
            this.ExternalOut3RunTime = "0";

            this.ExternalOut4Mode = "0";
            this.ExternalOut4DelayTime = "0";
            this.ExternalOut4RunTime = "0";

            this.ExternalOut9Mode = "0";
            this.ExternalOut9DelayTime = "0";
            this.ExternalOut9RunTime = "0";

            this.ExternalOut10Mode = "0";
            this.ExternalOut10DelayTime = "0";
            this.ExternalOut10RunTime = "0";

            this.Dummy1 = "0";
            this.Dummy2 = "0";
        }
        #endregion
    } 
    #endregion
    #region StructSystemParameter9509
    [StructLayout(LayoutKind.Sequential)]
    public struct StructSystemParameter9509
    {
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut1Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut1DelayTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut1RunTime;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut2Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut2DelayTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut2RunTime;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut3Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut3DelayTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut3RunTime;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut4Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut4DelayTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut4RunTime;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut9Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut9DelayTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut9RunTime;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut10Mode;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut10DelayTime;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string ExternalOut10RunTime;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy2;
    }
    #endregion
    #region SystemParameter9510
    /// <summary>
    /// 자동영점 1열 데이터
    /// </summary>
    public class SystemParameter9510
    {
        #region Field
        private string m_AutoZero1Range;
        private string m_AutoZero1Time;
        private string m_AutoZero1Variate;
        private string m_AutoZero1Mode;

        private string m_AutoZero2Mode;
        private string m_AutoZero2Range;
        private string m_AutoZero2Time;
        private string m_AutoZero2Variate;

        private string m_Dummy1;
        private string m_Dummy2;
        private string m_Dummy3;
        private string m_Dummy4;
        private string m_Dummy5;
        private string m_Dummy6;
        #endregion

        #region Constructor
        public SystemParameter9510()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public string AutoZero1Range
        {
            get { return this.m_AutoZero1Range; }
            set { this.m_AutoZero1Range = value; }
        }
        public string AutoZero1Time
        {
            get { return this.m_AutoZero1Time; }
            set { this.m_AutoZero1Time = value; }
        }
        public string AutoZero1Variate
        {
            get { return this.m_AutoZero1Variate; }
            set { this.m_AutoZero1Variate = value; }
        }
        public string AutoZero1Mode
        {
            get { return this.m_AutoZero1Mode; }
            set { this.m_AutoZero1Mode = value; }
        } 

        public string AutoZero2Mode
        {
            get { return this.m_AutoZero2Mode; }
            set { this.m_AutoZero2Mode = value; }
        }
        public string AutoZero2Range
        {
            get { return this.m_AutoZero2Range; }
            set { this.m_AutoZero2Range = value; }
        }
        public string AutoZero2Time
        {
            get { return this.m_AutoZero2Time; }
            set { this.m_AutoZero2Time = value; }
        }
        public string AutoZero2Variate
        {
            get { return this.m_AutoZero2Variate; }
            set { this.m_AutoZero2Variate = value; }
        }

        public string Dummy1
        {
            get { return this.m_Dummy1; }
            set { this.m_Dummy1 = value; }
        }
        public string Dummy2
        {
            get { return this.m_Dummy2; }
            set { this.m_Dummy2 = value; }
        }
        public string Dummy3
        {
            get { return this.m_Dummy3; }
            set { this.m_Dummy3 = value; }
        }
        public string Dummy4
        {
            get { return this.m_Dummy4; }
            set { this.m_Dummy4 = value; }
        }
        public string Dummy5
        {
            get { return this.m_Dummy5; }
            set { this.m_Dummy5 = value; }
        }
        public string Dummy6
        {
            get { return this.m_Dummy6; }
            set { this.m_Dummy6 = value; }
        }
        #endregion

        #region Method
        private void Initialization()
        {
            this.AutoZero1Range = "0";
            this.AutoZero1Time = "0";
            this.AutoZero1Variate = "0";
            this.AutoZero1Mode = "0";

            this.AutoZero2Mode = "0";
            this.AutoZero2Range = "0";
            this.AutoZero2Time = "0";
            this.AutoZero2Variate = "0";

            this.Dummy1 = "0";
            this.Dummy2 = "0";
            this.Dummy3 = "0";
            this.Dummy4 = "0";
            this.Dummy5 = "0";
            this.Dummy6 = "0";
        }
        #endregion
    } 
    #endregion
    #region StructSystemParameter9510
    [StructLayout(LayoutKind.Sequential)]
    public struct StructSystemParameter9510
    {
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Range;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Time;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Variate;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Mode;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Range;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Time;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Variate;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Mode;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy5;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy6;
    }
    #endregion
    #region SystemParameter9511
    /// <summary>
    /// 자동영점 2열 데이터
    /// </summary>
    public class SystemParameter9511
    {
        #region Field
        private string m_AutoZero1Range;
        private string m_AutoZero1Time;
        private string m_AutoZero1Variate;
        private string m_AutoZero1Mode;

        private string m_AutoZero2Mode;
        private string m_AutoZero2Range;
        private string m_AutoZero2Time;
        private string m_AutoZero2Variate;

        private string m_Dummy1;
        private string m_Dummy2;
        private string m_Dummy3;
        private string m_Dummy4;
        private string m_Dummy5;
        private string m_Dummy6;
        #endregion

        #region Constructor
        public SystemParameter9511()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public string AutoZero1Range
        {
            get { return this.m_AutoZero1Range; }
            set { this.m_AutoZero1Range = value; }
        }
        public string AutoZero1Time
        {
            get { return this.m_AutoZero1Time; }
            set { this.m_AutoZero1Time = value; }
        }
        public string AutoZero1Variate
        {
            get { return this.m_AutoZero1Variate; }
            set { this.m_AutoZero1Variate = value; }
        }
        public string AutoZero1Mode
        {
            get { return this.m_AutoZero1Mode; }
            set { this.m_AutoZero1Mode = value; }
        }

        public string AutoZero2Mode
        {
            get { return this.m_AutoZero2Mode; }
            set { this.m_AutoZero2Mode = value; }
        }
        public string AutoZero2Range
        {
            get { return this.m_AutoZero2Range; }
            set { this.m_AutoZero2Range = value; }
        }
        public string AutoZero2Time
        {
            get { return this.m_AutoZero2Time; }
            set { this.m_AutoZero2Time = value; }
        }
        public string AutoZero2Variate
        {
            get { return this.m_AutoZero2Variate; }
            set { this.m_AutoZero2Variate = value; }
        }

        public string Dummy1
        {
            get { return this.m_Dummy1; }
            set { this.m_Dummy1 = value; }
        }
        public string Dummy2
        {
            get { return this.m_Dummy2; }
            set { this.m_Dummy2 = value; }
        }
        public string Dummy3
        {
            get { return this.m_Dummy3; }
            set { this.m_Dummy3 = value; }
        }
        public string Dummy4
        {
            get { return this.m_Dummy4; }
            set { this.m_Dummy4 = value; }
        }
        public string Dummy5
        {
            get { return this.m_Dummy5; }
            set { this.m_Dummy5 = value; }
        }
        public string Dummy6
        {
            get { return this.m_Dummy6; }
            set { this.m_Dummy6 = value; }
        }
        #endregion

        #region Method
        private void Initialization()
        {
            this.AutoZero1Range = "0";
            this.AutoZero1Time = "0";
            this.AutoZero1Variate = "0";
            this.AutoZero1Mode = "0";

            this.AutoZero2Mode = "0";
            this.AutoZero2Range = "0";
            this.AutoZero2Time = "0";
            this.AutoZero2Variate = "0";

            this.Dummy1 = "0";
            this.Dummy2 = "0";
            this.Dummy3 = "0";
            this.Dummy4 = "0";
            this.Dummy5 = "0";
            this.Dummy6 = "0";
        }
        #endregion
    }
    #endregion
    #region StructSystemParameter9511
    [StructLayout(LayoutKind.Sequential)]
    public struct StructSystemParameter9511
    {
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Range;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Time;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Variate;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero1Mode;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Range;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Time;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Variate;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string AutoZero2Mode;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy5;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 10)]
        public string Dummy6;
    }
    #endregion

    #region SystemStatus
    public class SystemStatus
    {
        #region Field
        private DataStore.EquipmentStatus m_Equipment;
        private DataStore.DisplayStore m_CurrentDisplay;
        private DataStore.DisplayMode m_CurrentMode;
        private DataStore.WeightInputMode m_CurrentWeightInputMode;

        private UserPasswordType m_CurrentUserPasswordType;
        private UserItem m_CurrentUser;
        #endregion

        #region Constructor
        public SystemStatus()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public DataStore.EquipmentStatus Equipment
        {
            get { return this.m_Equipment; }
            set { this.m_Equipment = value; }
        }
        public DataStore.DisplayStore CurrentDisplay
        {
            get { return this.m_CurrentDisplay; }
            set { this.m_CurrentDisplay = value; }
        }
        public DataStore.DisplayMode CurrentMode
        {
            get { return this.m_CurrentMode; }
            set { this.m_CurrentMode = value; }
        }
        public DataStore.WeightInputMode CurrentWeightInputMode
        {
            get { return this.m_CurrentWeightInputMode; }
            set { this.m_CurrentWeightInputMode = value; }
        }
       
        public UserPasswordType CurrentUserPasswordType
        {
            get { return this.m_CurrentUserPasswordType; }
            set { this.m_CurrentUserPasswordType = value; }
        }
        public UserItem CurrentUser
        {
            get { return this.m_CurrentUser; }
            set { this.m_CurrentUser = value; }
        } 
        #endregion

        #region Method
        public void Initialization()
        {
            this.Equipment = DataStore.EquipmentStatus.Stop;
            this.CurrentDisplay = DataStore.DisplayStore.MainDisplay;
            this.CurrentMode = DataStore.DisplayMode.Normal;
            this.CurrentWeightInputMode = DataStore.WeightInputMode.Weight;
            this.CurrentUserPasswordType = new UserPasswordType();
            
            this.CurrentUser = new UserItem();
            this.CurrentUser.ID = "";
            this.CurrentUser.Password = "";
            this.CurrentUser.Group = DataStore.UserGroup.LogOff;
        }
        #endregion
    }
    #endregion

    #region UserPasswordType
    public class UserPasswordType
    {
        #region Field
        private string m_Level1Password;
        private string m_Level2Password;
        private string m_Level3Password;
        private string m_Level4Password;

        private DataStore.UserGroup m_Group;
        #endregion

        #region Constructor
        public UserPasswordType()
        {
            this.Initialization();
        }
        #endregion

        #region Property
        public string Level1Password
        {
            get { return this.m_Level1Password; }
            set { this.m_Level1Password = value; }
        }
        public string Level2Password
        {
            get { return this.m_Level2Password; }
            set { this.m_Level2Password = value; }
        }
        public string Level3Password
        {
            get { return this.m_Level3Password; }
            set { this.m_Level3Password = value; }
        }
        public string Level4Password
        {
            get { return this.m_Level4Password; }
            set { this.m_Level4Password = value; }
        }

        public DataStore.UserGroup Group
        {
            get { return this.m_Group; }
            set { this.m_Group = value; }
        }
        #endregion

        #region Method
        public void Initialization()
        {
            this.Level1Password = "1000";
            this.Level2Password = "2000";
            this.Level3Password = "3000";
            this.Level4Password = "0714";

            this.Group = DataStore.UserGroup.None;
        }
        #endregion
    }
    #endregion

    #region User
    public class User
    {
        #region Field
        private Collection<UserItem> m_Level1Users;
        private Collection<UserItem> m_Level2Users;
        private Collection<UserItem> m_Level3Users;

        private UserItem m_DeveloperUser;
        #endregion

        #region Constructor
        public User()
        {
            this.Initialize();
        }
        #endregion

        #region Property
        public Collection<UserItem> Level1Users
        {
            get { return this.m_Level1Users; }
            set { this.m_Level1Users = value; }
        }
        public Collection<UserItem> Level2Users
        {
            get { return this.m_Level2Users; }
            set { this.m_Level2Users = value; }
        }
        public Collection<UserItem> Level3Users
        {
            get { return this.m_Level3Users; }
            set { this.m_Level3Users = value; }
        }

        public UserItem DeveloperUser
        {
            get { return this.m_DeveloperUser; }
            private set { this.m_DeveloperUser = value; }
        } 
        #endregion

        #region Method
        private void Initialize()
        {
            this.Level1Users = new Collection<UserItem>();
            this.Level2Users = new Collection<UserItem>();
            this.Level3Users = new Collection<UserItem>();

            this.Level1Users.Clear();
            this.Level2Users.Clear();
            this.Level3Users.Clear();

            for (int i = 0; i < 5; i++)
            {
                this.Level1Users.Add(new UserItem());
                this.Level2Users.Add(new UserItem());
                this.Level3Users.Add(new UserItem());
            }

            this.DeveloperUser = new UserItem();
            this.DeveloperUser.ID = "Intech";
            this.DeveloperUser.Password = "20090810";
            this.DeveloperUser.Group = DataStore.UserGroup.Level4Developer;
        }
        
        public UserItem FindUser(string id)
        {
            UserItem user = null;

            // 개발자 유저 검색
            if (id == this.DeveloperUser.ID)
            {
                user = new UserItem();
                user.ID = this.DeveloperUser.ID;
                user.Password = this.DeveloperUser.Password;
                user.Group = this.DeveloperUser.Group;
                return user;
            }
            
            // 일반 유저 검색
            for (int i = 0; i < this.Level1Users.Count; i++)
            {
                if (this.Level1Users[i].Group != DataStore.UserGroup.None)
                {
                    if (this.Level1Users[i].ID.Trim() == id.Trim())
                    {
                        user = new UserItem();
                        user.ID = this.Level1Users[i].ID.Trim();
                        user.Password = this.Level1Users[i].Password;
                        user.Group = this.Level1Users[i].Group;
                        return user;
                    }
                }

                if (this.Level2Users[i].Group != DataStore.UserGroup.None)
                {
                    if (this.Level2Users[i].ID.Trim() == id.Trim())
                    {
                        user = new UserItem();
                        user.ID = this.Level2Users[i].ID.Trim();
                        user.Password = this.Level2Users[i].Password;
                        user.Group = this.Level2Users[i].Group;
                        return user;
                    }
                }

                if (this.Level3Users[i].Group != DataStore.UserGroup.None)
                {
                    if (this.Level3Users[i].ID.Trim() == id.Trim())
                    {
                        user = new UserItem();
                        user.ID = this.Level3Users[i].ID.Trim();
                        user.Password = this.Level3Users[i].Password;
                        user.Group = this.Level3Users[i].Group;
                        return user;
                    }
                }
            }

            return user;
        }
        public UserItem FindDeveloperUser(string id)
        {
            UserItem user = null;

            // 개발자 유저 검색
            if (id == this.DeveloperUser.ID)
            {
                user = new UserItem();
                user.ID = this.DeveloperUser.ID;
                user.Password = this.DeveloperUser.Password;
                user.Group = this.DeveloperUser.Group;
                return user;
            }

            return user;
        }
        
        public bool SearchID(string id)
        {
            bool ret = false;

            for (int i = 0; i < this.Level1Users.Count; i++)
            {
                if (this.Level1Users[i].ID.Trim() == id.Trim())
                    return ret = true;
            }
            for (int i = 0; i < this.Level2Users.Count; i++)
            {
                if (this.Level2Users[i].ID.Trim() == id.Trim())
                    return ret = true;
            }
            for (int i = 0; i < this.Level3Users.Count; i++)
            {
                if (this.Level3Users[i].ID.Trim() == id.Trim())
                    return ret = true;
            }

            return ret;
        }
       
        #region Level1
        public UserItem Level1FindUser(string id)
        {
            UserItem user = null;

            for (int i = 0; i < this.Level1Users.Count; i++)
            {
                if (this.Level1Users[i].ID.Trim() == id.Trim())
                {
                    user = new UserItem();
                    user.ID = this.Level1Users[i].ID.Trim();
                    user.Password = this.Level1Users[i].Password;
                    user.Group = this.Level1Users[i].Group;
                    return user;
                }
            }

            return user;
        }
        public bool Level1SearchID(string id)
        {
            bool ret = false;

            for (int i = 0; i < this.Level1Users.Count; i++)
            {
                if (this.Level1Users[i].ID.Trim() == id.Trim())
                    return ret = true;
            }

            return ret;
        }
        public bool Level1DeleteLevel1User(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        public bool Level1AddUser(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        public bool Level1ModifyUser(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        #endregion
        #region Level2
        public UserItem Level2FindUser(string id)
        {
            UserItem user = null;

            for (int i = 0; i < this.Level2Users.Count; i++)
            {
                if (this.Level2Users[i].ID.Trim() == id.Trim())
                {
                    user = new UserItem();
                    user.ID = this.Level2Users[i].ID.Trim();
                    user.Password = this.Level2Users[i].Password;
                    user.Group = this.Level2Users[i].Group;
                    return user;
                }
            }

            return user;
        }
        public bool Level2DeleteLevel1User(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        public bool Level2AddUser(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        public bool Level2ModifyUser(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        #endregion
        #region Level3
        public UserItem Level3FindUser(string id)
        {
            UserItem user = null;

            for (int i = 0; i < this.Level3Users.Count; i++)
            {
                if (this.Level3Users[i].ID.Trim() == id.Trim())
                {
                    user = new UserItem();
                    user.ID = this.Level3Users[i].ID.Trim();
                    user.Password = this.Level3Users[i].Password;
                    user.Group = this.Level3Users[i].Group;
                    return user;
                }
            }

            return user;
        }
        public bool Level3DeleteLevel1User(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        public bool Level3AddUser(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        public bool Level3ModifyUser(UserItem user)
        {
            bool ret = false;

            return ret;
        }
        #endregion
        
        #endregion
    } 
    #endregion
    #region UserItem
    public class UserItem
    {
        #region Field
        private string m_ID;
        private string m_Password;
        private DataStore.UserGroup m_Group;
        #endregion

        #region Constructor
        public UserItem()
        {
            this.Initialize();
        }
        #endregion

        #region Property
        public string ID
        {
            get { return this.m_ID; }
            set { this.m_ID = value; }
        }
        public string Password
        {
            get { return this.m_Password; }
            set { this.m_Password = value; }
        }
        public DataStore.UserGroup Group
        {
            get { return this.m_Group; }
            set { this.m_Group = value; }
        } 
        #endregion

        #region Method
        private void Initialize()
        {
            this.ID = "-";
            this.Password = "-";
            this.Group = DataStore.UserGroup.None;
        }
        #endregion
    }
    #endregion
    #region StructUserItem
    [StructLayout(LayoutKind.Sequential)]
    public struct StructUserItem
    {
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string ID;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string Password;

        public DataStore.UserGroup Group;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string Dummy1;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string Dummy2;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string Dummy3;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string Dummy4;
        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 20)]
        public string Dummy5;
    }
    #endregion

    #region UserGroup
    public class UserGroup
    {
        #region Field
        private UserGroupItem m_Level1;
        private UserGroupItem m_Level2;
        private UserGroupItem m_Level3;
        #endregion

        #region Constructor
        public UserGroup()
        {
            this.Initialize();
        }
        #endregion

        #region Property
        public UserGroupItem Level1
        {
            get { return this.m_Level1; }
            set { this.m_Level1 = value; }
        }
        public UserGroupItem Level2
        {
            get { return this.m_Level2; }
            set { this.m_Level2 = value; }
        }
        public UserGroupItem Level3
        {
            get { return this.m_Level3; }
            set { this.m_Level3 = value; }
        }
        #endregion

        #region Method
        private void Initialize()
        {
            this.Level1 = new UserGroupItem();
            this.Level2 = new UserGroupItem();
            this.Level3 = new UserGroupItem();
        }

        public bool GetLevel1AccessRight(DataStore.DisplayStore display)
        {
            bool ret = false;

            return ret;
        }
        public bool GetLevel2AccessRight(DataStore.DisplayStore display)
        {
            bool ret = false;

            return ret;
        }
        public bool GetLevel3AccessRight(DataStore.DisplayStore display)
        {
            bool ret = false;

            return ret;
        }
        #endregion
    } 
    #endregion
    #region UserGroupItem
    public class UserGroupItem
    {
        #region Field
        private bool m_IsBasic;
        private bool m_IsConfiguration;
        private bool m_IsSystem;
        private bool m_IsEquipment;
        private bool m_IsInformation;

        private bool m_IsBasicTime;
        private bool m_IsBasicProduct;
        private bool m_IsBasicDataBackup;
        private bool m_IsBasicDataStatistics;

        private bool m_IsConfiCommunication;
        private bool m_IsConfiOption;

        private bool m_IsSystemCalibration;
        private bool m_IsSystemJudgmentSetting;
        private bool m_IsSystemSorterSetting;
        private bool m_IsSystemAutoZero;
        private bool m_IsSystemIOTest;
        private bool m_IsSystemExternalOutput;

        private bool m_IsEquipUpdate;
        private bool m_IsEquipInitialize;
        private bool m_IsEquipFunctionSetting;
        private bool m_IsEquipUser;

        private bool m_IsInforSystem;
        private bool m_IsInforAS;
        #endregion

        #region Constructor
        public UserGroupItem()
        {
            this.Initialize();
        }
        #endregion

        #region Property
        public bool IsBasic
        {
            get { return this.m_IsBasic; }
            set { this.m_IsBasic = value; }
        }
        public bool IsConfiguration
        {
            get { return this.m_IsConfiguration; }
            set { this.m_IsConfiguration = value; }
        }
        public bool IsSystem
        {
            get { return this.m_IsSystem; }
            set { this.m_IsSystem = value; }
        }
        public bool IsEquipment
        {
            get { return this.m_IsEquipment; }
            set { this.m_IsEquipment = value; }
        }
        public bool IsInformation
        {
            get { return this.m_IsInformation; }
            set { this.m_IsInformation = value; }
        } 

        public bool IsBasicTime
        {
            get { return this.m_IsBasicTime; }
            set { this.m_IsBasicTime = value; }
        }
        public bool IsBasicProduct
        {
            get { return this.m_IsBasicProduct; }
            set { this.m_IsBasicProduct = value; }
        }
        public bool IsBasicDataBackup
        {
            get { return this.m_IsBasicDataBackup; }
            set { this.m_IsBasicDataBackup = value; }
        }
        public bool IsBasicDataStatistics
        {
            get { return this.m_IsBasicDataStatistics; }
            set { this.m_IsBasicDataStatistics = value; }
        }

        public bool IsConfiCommunication
        {
            get { return this.m_IsConfiCommunication; }
            set { this.m_IsConfiCommunication = value; }
        }
        public bool IsConfiOption
        {
            get { return this.m_IsConfiOption; }
            set { this.m_IsConfiOption = value; }
        }
        
        public bool IsSystemCalibration
        {
            get { return this.m_IsSystemCalibration; }
            set { this.m_IsSystemCalibration = value; }
        }
        public bool IsSystemJudgmentSetting
        {
            get { return this.m_IsSystemJudgmentSetting; }
            set { this.m_IsSystemJudgmentSetting = value; }
        }
        public bool IsSystemSorterSetting
        {
            get { return this.m_IsSystemSorterSetting; }
            set { this.m_IsSystemSorterSetting = value; }
        }
        public bool IsSystemAutoZero
        {
            get { return this.m_IsSystemAutoZero; }
            set { this.m_IsSystemAutoZero = value; }
        }
        public bool IsSystemIOTest
        {
            get { return this.m_IsSystemIOTest; }
            set { this.m_IsSystemIOTest = value; }
        }
        public bool IsSystemExternalOutput
        {
            get { return this.m_IsSystemExternalOutput; }
            set { this.m_IsSystemExternalOutput = value; }
        }

        public bool IsEquipUpdate
        {
            get { return this.m_IsEquipUpdate; }
            set { this.m_IsEquipUpdate = value; }
        }
        public bool IsEquipInitialize
        {
            get { return this.m_IsEquipInitialize; }
            set { this.m_IsEquipInitialize = value; }
        }
        public bool IsEquipFunctionSetting
        {
            get { return this.m_IsEquipFunctionSetting; }
            set { this.m_IsEquipFunctionSetting = value; }
        }
        public bool IsEquipUser
        {
            get { return this.m_IsEquipUser; }
            set { this.m_IsEquipUser = value; }
        }

        public bool IsInforSystem
        {
            get { return this.m_IsInforSystem; }
            set { this.m_IsInforSystem = value; }
        }
        public bool IsInforAS
        {
            get { return this.m_IsInforAS; }
            set { this.m_IsInforAS = value; }
        } 
        #endregion

        #region Method
        private void Initialize()
        {
            this.IsBasic = false;
            this.IsConfiguration = false;
            this.IsSystem = false;
            this.IsEquipment = false;
            this.IsInformation = false;
                
            this.IsBasicTime = false;
            this.IsBasicProduct = false;
            this.IsBasicDataBackup = false;
            this.IsBasicDataStatistics = false;

            this.IsConfiCommunication = false;
            this.IsConfiOption = false;

            this.IsSystemCalibration = false;
            this.IsSystemJudgmentSetting = false;
            this.IsSystemSorterSetting = false;
            this.IsSystemAutoZero = false;
            this.IsSystemIOTest = false;
            this.IsSystemExternalOutput = false;

            this.IsEquipUpdate = false;
            this.IsEquipInitialize = false;
            this.IsEquipFunctionSetting = false;
            this.IsEquipUser = false;

            this.IsInforSystem = false;
            this.IsInforAS = false;
        }
        #endregion
    }
    #endregion
    #region StructUserGroupItem
    [StructLayout(LayoutKind.Sequential)]
    public struct StructUserGroupItem
    {
        public bool IsBasic;
        public bool IsConfiguration;
        public bool IsSystem;
        public bool IsEquipment;
        public bool IsInformation;

        public bool IsBasicTime;
        public bool IsBasicProduct;
        public bool IsBasicDataBackup;
        public bool IsBasicDataStatistics;

        public bool IsConfiCommunication;
        public bool IsConfiOption;

        public bool IsSystemCalibration;
        public bool IsSystemJudgmentSetting;
        public bool IsSystemSorterSetting;
        public bool IsSystemAutoZero;
        public bool IsSystemIOTest;
        public bool IsSystemExternalOutput;

        public bool IsEquipUpdate;
        public bool IsEquipInitialize;
        public bool IsEquipFunctionSetting;
        public bool IsEquipUser;

        public bool IsInforSystem;
        public bool IsInforAS;

        public bool Dummy1;
        public bool Dummy2;
        public bool Dummy3;
        public bool Dummy4;
        public bool Dummy5;
        public bool Dummy6;
        public bool Dummy7;
        public bool Dummy8;
        public bool Dummy9;
        public bool Dummy10;
        public bool Dummy11;
        public bool Dummy12;
        public bool Dummy13;
        public bool Dummy14;
        public bool Dummy15;
        public bool Dummy16;
        public bool Dummy17;
        public bool Dummy18;
        public bool Dummy19;
        public bool Dummy20;
    }
    #endregion
}
